Class: Aws::ApplicationInsights::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ApplicationInsights::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-applicationinsights/client.rb,
sig/client.rbs
Overview
An API client for ApplicationInsights. To construct a client, you need to configure a :region and :credentials.
client = Aws::ApplicationInsights::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AddWorkloadResponseSuccess, _CreateApplicationResponseSuccess, _CreateComponentResponseSuccess, _CreateLogPatternResponseSuccess, _DeleteApplicationResponseSuccess, _DeleteComponentResponseSuccess, _DeleteLogPatternResponseSuccess, _DescribeApplicationResponseSuccess, _DescribeComponentConfigurationRecommendationResponseSuccess, _DescribeComponentConfigurationResponseSuccess, _DescribeComponentResponseSuccess, _DescribeLogPatternResponseSuccess, _DescribeObservationResponseSuccess, _DescribeProblemObservationsResponseSuccess, _DescribeProblemResponseSuccess, _DescribeWorkloadResponseSuccess, _ListApplicationsResponseSuccess, _ListComponentsResponseSuccess, _ListConfigurationHistoryResponseSuccess, _ListLogPatternSetsResponseSuccess, _ListLogPatternsResponseSuccess, _ListProblemsResponseSuccess, _ListTagsForResourceResponseSuccess, _ListWorkloadsResponseSuccess, _RemoveWorkloadResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateApplicationResponseSuccess, _UpdateComponentConfigurationResponseSuccess, _UpdateComponentResponseSuccess, _UpdateLogPatternResponseSuccess, _UpdateProblemResponseSuccess, _UpdateWorkloadResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#add_workload(params = {}) ⇒ Types::AddWorkloadResponse
Adds a workload to a component.
-
#create_application(params = {}) ⇒ Types::CreateApplicationResponse
Adds an application that is created from a resource group.
-
#create_component(params = {}) ⇒ Struct
Creates a custom component by grouping similar standalone instances to monitor.
-
#create_log_pattern(params = {}) ⇒ Types::CreateLogPatternResponse
Adds an log pattern to a
LogPatternSet. -
#delete_application(params = {}) ⇒ Struct
Removes the specified application from monitoring.
-
#delete_component(params = {}) ⇒ Struct
Ungroups a custom component.
-
#delete_log_pattern(params = {}) ⇒ Struct
Removes the specified log pattern from a
LogPatternSet. -
#describe_application(params = {}) ⇒ Types::DescribeApplicationResponse
Describes the application.
-
#describe_component(params = {}) ⇒ Types::DescribeComponentResponse
Describes a component and lists the resources that are grouped together in a component.
-
#describe_component_configuration(params = {}) ⇒ Types::DescribeComponentConfigurationResponse
Describes the monitoring configuration of the component.
-
#describe_component_configuration_recommendation(params = {}) ⇒ Types::DescribeComponentConfigurationRecommendationResponse
Describes the recommended monitoring configuration of the component.
-
#describe_log_pattern(params = {}) ⇒ Types::DescribeLogPatternResponse
Describe a specific log pattern from a
LogPatternSet. -
#describe_observation(params = {}) ⇒ Types::DescribeObservationResponse
Describes an anomaly or error with the application.
-
#describe_problem(params = {}) ⇒ Types::DescribeProblemResponse
Describes an application problem.
-
#describe_problem_observations(params = {}) ⇒ Types::DescribeProblemObservationsResponse
Describes the anomalies or errors associated with the problem.
-
#describe_workload(params = {}) ⇒ Types::DescribeWorkloadResponse
Describes a workload and its configuration.
-
#list_applications(params = {}) ⇒ Types::ListApplicationsResponse
Lists the IDs of the applications that you are monitoring.
-
#list_components(params = {}) ⇒ Types::ListComponentsResponse
Lists the auto-grouped, standalone, and custom components of the application.
-
#list_configuration_history(params = {}) ⇒ Types::ListConfigurationHistoryResponse
Lists the INFO, WARN, and ERROR events for periodic configuration updates performed by Application Insights.
-
#list_log_pattern_sets(params = {}) ⇒ Types::ListLogPatternSetsResponse
Lists the log pattern sets in the specific application.
-
#list_log_patterns(params = {}) ⇒ Types::ListLogPatternsResponse
Lists the log patterns in the specific log
LogPatternSet. -
#list_problems(params = {}) ⇒ Types::ListProblemsResponse
Lists the problems with your application.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Retrieve a list of the tags (keys and values) that are associated with a specified application.
-
#list_workloads(params = {}) ⇒ Types::ListWorkloadsResponse
Lists the workloads that are configured on a given component.
-
#remove_workload(params = {}) ⇒ Struct
Remove workload from a component.
-
#tag_resource(params = {}) ⇒ Struct
Add one or more tags (keys and values) to a specified application.
-
#untag_resource(params = {}) ⇒ Struct
Remove one or more tags (keys and values) from a specified application.
-
#update_application(params = {}) ⇒ Types::UpdateApplicationResponse
Updates the application.
-
#update_component(params = {}) ⇒ Struct
Updates the custom component name and/or the list of resources that make up the component.
-
#update_component_configuration(params = {}) ⇒ Struct
Updates the monitoring configurations for the component.
-
#update_log_pattern(params = {}) ⇒ Types::UpdateLogPatternResponse
Adds a log pattern to a
LogPatternSet. -
#update_problem(params = {}) ⇒ Struct
Updates the visibility of the problem or specifies the problem as
RESOLVED. -
#update_workload(params = {}) ⇒ Types::UpdateWorkloadResponse
Adds a workload to a component.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-applicationinsights/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2198 2199 2200 |
# File 'lib/aws-sdk-applicationinsights/client.rb', line 2198 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2201 2202 2203 |
# File 'lib/aws-sdk-applicationinsights/client.rb', line 2201 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#add_workload(params = {}) ⇒ Types::AddWorkloadResponse
Adds a workload to a component. Each component can have at most five workloads.
88 |
# File 'sig/client.rbs', line 88
def add_workload: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2171 2172 2173 2174 2175 2176 2177 2178 2179 2180 2181 2182 2183 2184 2185 2186 2187 |
# File 'lib/aws-sdk-applicationinsights/client.rb', line 2171 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ApplicationInsights') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-applicationinsights' context[:gem_version] = '1.82.0' Seahorse::Client::Request.new(handlers, context) end |
#create_application(params = {}) ⇒ Types::CreateApplicationResponse
Adds an application that is created from a resource group.
104 |
# File 'sig/client.rbs', line 104
def create_application: (
|
#create_component(params = {}) ⇒ Struct
Creates a custom component by grouping similar standalone instances to monitor.
127 |
# File 'sig/client.rbs', line 127
def create_component: (
|
#create_log_pattern(params = {}) ⇒ Types::CreateLogPatternResponse
Adds an log pattern to a LogPatternSet.
140 |
# File 'sig/client.rbs', line 140
def create_log_pattern: (
|
#delete_application(params = {}) ⇒ Struct
Removes the specified application from monitoring. Does not delete the application.
153 |
# File 'sig/client.rbs', line 153
def delete_application: (
|
#delete_component(params = {}) ⇒ Struct
Ungroups a custom component. When you ungroup custom components, all applicable monitors that are set up for the component are removed and the instances revert to their standalone status.
162 |
# File 'sig/client.rbs', line 162
def delete_component: (
|
#delete_log_pattern(params = {}) ⇒ Struct
Removes the specified log pattern from a LogPatternSet.
172 |
# File 'sig/client.rbs', line 172
def delete_log_pattern: (
|
#describe_application(params = {}) ⇒ Types::DescribeApplicationResponse
Describes the application.
184 |
# File 'sig/client.rbs', line 184
def describe_application: (
|
#describe_component(params = {}) ⇒ Types::DescribeComponentResponse
Describes a component and lists the resources that are grouped together in a component.
196 |
# File 'sig/client.rbs', line 196
def describe_component: (
|
#describe_component_configuration(params = {}) ⇒ Types::DescribeComponentConfigurationResponse
Describes the monitoring configuration of the component.
210 |
# File 'sig/client.rbs', line 210
def describe_component_configuration: (
|
#describe_component_configuration_recommendation(params = {}) ⇒ Types::DescribeComponentConfigurationRecommendationResponse
Describes the recommended monitoring configuration of the component.
222 |
# File 'sig/client.rbs', line 222
def describe_component_configuration_recommendation: (
|
#describe_log_pattern(params = {}) ⇒ Types::DescribeLogPatternResponse
Describe a specific log pattern from a LogPatternSet.
238 |
# File 'sig/client.rbs', line 238
def describe_log_pattern: (
|
#describe_observation(params = {}) ⇒ Types::DescribeObservationResponse
Describes an anomaly or error with the application.
251 |
# File 'sig/client.rbs', line 251
def describe_observation: (
|
#describe_problem(params = {}) ⇒ Types::DescribeProblemResponse
Describes an application problem.
263 |
# File 'sig/client.rbs', line 263
def describe_problem: (
|
#describe_problem_observations(params = {}) ⇒ Types::DescribeProblemObservationsResponse
Describes the anomalies or errors associated with the problem.
274 |
# File 'sig/client.rbs', line 274
def describe_problem_observations: (
|
#describe_workload(params = {}) ⇒ Types::DescribeWorkloadResponse
Describes a workload and its configuration.
287 |
# File 'sig/client.rbs', line 287
def describe_workload: (
|
#list_applications(params = {}) ⇒ Types::ListApplicationsResponse
Lists the IDs of the applications that you are monitoring.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
301 |
# File 'sig/client.rbs', line 301
def list_applications: (
|
#list_components(params = {}) ⇒ Types::ListComponentsResponse
Lists the auto-grouped, standalone, and custom components of the application.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
314 |
# File 'sig/client.rbs', line 314
def list_components: (
|
#list_configuration_history(params = {}) ⇒ Types::ListConfigurationHistoryResponse
Lists the INFO, WARN, and ERROR events for periodic configuration updates performed by Application Insights. Examples of events represented are:
-
INFO: creating a new alarm or updating an alarm threshold.
-
WARN: alarm not created due to insufficient data points used to predict thresholds.
-
ERROR: alarm not created due to permission errors or exceeding quotas.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
328 |
# File 'sig/client.rbs', line 328
def list_configuration_history: (
|
#list_log_pattern_sets(params = {}) ⇒ Types::ListLogPatternSetsResponse
Lists the log pattern sets in the specific application.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
347 |
# File 'sig/client.rbs', line 347
def list_log_pattern_sets: (
|
#list_log_patterns(params = {}) ⇒ Types::ListLogPatternsResponse
Lists the log patterns in the specific log LogPatternSet.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
363 |
# File 'sig/client.rbs', line 363
def list_log_patterns: (
|
#list_problems(params = {}) ⇒ Types::ListProblemsResponse
Lists the problems with your application.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
380 |
# File 'sig/client.rbs', line 380
def list_problems: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Retrieve a list of the tags (keys and values) that are associated with a specified application. A tag is a label that you optionally define and associate with an application. Each tag consists of a required tag key and an optional associated tag value. A tag key is a general label that acts as a category for more specific tag values. A tag value acts as a descriptor within a tag key.
397 |
# File 'sig/client.rbs', line 397
def list_tags_for_resource: (
|
#list_workloads(params = {}) ⇒ Types::ListWorkloadsResponse
Lists the workloads that are configured on a given component.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
408 |
# File 'sig/client.rbs', line 408
def list_workloads: (
|
#remove_workload(params = {}) ⇒ Struct
Remove workload from a component.
421 |
# File 'sig/client.rbs', line 421
def remove_workload: (
|
#tag_resource(params = {}) ⇒ Struct
Add one or more tags (keys and values) to a specified application. A tag is a label that you optionally define and associate with an application. Tags can help you categorize and manage application in different ways, such as by purpose, owner, environment, or other criteria.
Each tag consists of a required tag key and an associated tag value, both of which you define. A tag key is a general label that acts as a category for more specific tag values. A tag value acts as a descriptor within a tag key.
432 |
# File 'sig/client.rbs', line 432
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Remove one or more tags (keys and values) from a specified application.
447 |
# File 'sig/client.rbs', line 447
def untag_resource: (
|
#update_application(params = {}) ⇒ Types::UpdateApplicationResponse
Updates the application.
458 |
# File 'sig/client.rbs', line 458
def update_application: (
|
#update_component(params = {}) ⇒ Struct
Updates the custom component name and/or the list of resources that make up the component.
474 |
# File 'sig/client.rbs', line 474
def update_component: (
|
#update_component_configuration(params = {}) ⇒ Struct
Updates the monitoring configurations for the component. The
configuration input parameter is an escaped JSON of the configuration
and should match the schema of what is returned by
DescribeComponentConfigurationRecommendation.
486 |
# File 'sig/client.rbs', line 486
def update_component_configuration: (
|
#update_log_pattern(params = {}) ⇒ Types::UpdateLogPatternResponse
Adds a log pattern to a LogPatternSet.
502 |
# File 'sig/client.rbs', line 502
def update_log_pattern: (
|
#update_problem(params = {}) ⇒ Struct
Updates the visibility of the problem or specifies the problem as
RESOLVED.
515 |
# File 'sig/client.rbs', line 515
def update_problem: (
|
#update_workload(params = {}) ⇒ Types::UpdateWorkloadResponse
Adds a workload to a component. Each component can have at most five workloads.
528 |
# File 'sig/client.rbs', line 528
def update_workload: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2191 2192 2193 |
# File 'lib/aws-sdk-applicationinsights/client.rb', line 2191 def waiter_names [] end |