Class: Aws::ApplicationInsights::Types::ApplicationComponent

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-applicationinsights/types.rb

Overview

Describes a standalone resource or similarly grouped resources that the application is made up of.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#component_nameString

The name of the component.



102
103
104
105
106
107
108
109
110
111
112
# File 'lib/aws-sdk-applicationinsights/types.rb', line 102

class ApplicationComponent < Struct.new(
  :component_name,
  :component_remarks,
  :resource_type,
  :os_type,
  :tier,
  :monitor,
  :detected_workload)
  SENSITIVE = []
  include Aws::Structure
end

#component_remarksString

If logging is supported for the resource type, indicates whether the component has configured logs to be monitored.



102
103
104
105
106
107
108
109
110
111
112
# File 'lib/aws-sdk-applicationinsights/types.rb', line 102

class ApplicationComponent < Struct.new(
  :component_name,
  :component_remarks,
  :resource_type,
  :os_type,
  :tier,
  :monitor,
  :detected_workload)
  SENSITIVE = []
  include Aws::Structure
end

#detected_workloadHash<String,Hash<String,String>>

Workloads detected in the application component.



102
103
104
105
106
107
108
109
110
111
112
# File 'lib/aws-sdk-applicationinsights/types.rb', line 102

class ApplicationComponent < Struct.new(
  :component_name,
  :component_remarks,
  :resource_type,
  :os_type,
  :tier,
  :monitor,
  :detected_workload)
  SENSITIVE = []
  include Aws::Structure
end

#monitorBoolean

Indicates whether the application component is monitored.



102
103
104
105
106
107
108
109
110
111
112
# File 'lib/aws-sdk-applicationinsights/types.rb', line 102

class ApplicationComponent < Struct.new(
  :component_name,
  :component_remarks,
  :resource_type,
  :os_type,
  :tier,
  :monitor,
  :detected_workload)
  SENSITIVE = []
  include Aws::Structure
end

#os_typeString

The operating system of the component.



102
103
104
105
106
107
108
109
110
111
112
# File 'lib/aws-sdk-applicationinsights/types.rb', line 102

class ApplicationComponent < Struct.new(
  :component_name,
  :component_remarks,
  :resource_type,
  :os_type,
  :tier,
  :monitor,
  :detected_workload)
  SENSITIVE = []
  include Aws::Structure
end

#resource_typeString

The resource type. Supported resource types include EC2 instances, Auto Scaling group, Classic ELB, Application ELB, and SQS Queue.



102
103
104
105
106
107
108
109
110
111
112
# File 'lib/aws-sdk-applicationinsights/types.rb', line 102

class ApplicationComponent < Struct.new(
  :component_name,
  :component_remarks,
  :resource_type,
  :os_type,
  :tier,
  :monitor,
  :detected_workload)
  SENSITIVE = []
  include Aws::Structure
end

#tierString

The stack tier of the application component.



102
103
104
105
106
107
108
109
110
111
112
# File 'lib/aws-sdk-applicationinsights/types.rb', line 102

class ApplicationComponent < Struct.new(
  :component_name,
  :component_remarks,
  :resource_type,
  :os_type,
  :tier,
  :monitor,
  :detected_workload)
  SENSITIVE = []
  include Aws::Structure
end