Class: Aws::ApplicationInsights::Types::ApplicationInfo

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-applicationinsights/types.rb

Overview

Describes the status of the application.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_idString

The Amazon Web Services account ID for the owner of the application.



175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/aws-sdk-applicationinsights/types.rb', line 175

class ApplicationInfo < Struct.new(
  :account_id,
  :resource_group_name,
  :life_cycle,
  :ops_item_sns_topic_arn,
  :sns_notification_arn,
  :ops_center_enabled,
  :cwe_monitor_enabled,
  :remarks,
  :auto_config_enabled,
  :discovery_type,
  :attach_missing_permission)
  SENSITIVE = []
  include Aws::Structure
end

#attach_missing_permissionBoolean

If set to true, the managed policies for SSM and CW will be attached to the instance roles if they are missing.



175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/aws-sdk-applicationinsights/types.rb', line 175

class ApplicationInfo < Struct.new(
  :account_id,
  :resource_group_name,
  :life_cycle,
  :ops_item_sns_topic_arn,
  :sns_notification_arn,
  :ops_center_enabled,
  :cwe_monitor_enabled,
  :remarks,
  :auto_config_enabled,
  :discovery_type,
  :attach_missing_permission)
  SENSITIVE = []
  include Aws::Structure
end

#auto_config_enabledBoolean

Indicates whether auto-configuration is turned on for this application.



175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/aws-sdk-applicationinsights/types.rb', line 175

class ApplicationInfo < Struct.new(
  :account_id,
  :resource_group_name,
  :life_cycle,
  :ops_item_sns_topic_arn,
  :sns_notification_arn,
  :ops_center_enabled,
  :cwe_monitor_enabled,
  :remarks,
  :auto_config_enabled,
  :discovery_type,
  :attach_missing_permission)
  SENSITIVE = []
  include Aws::Structure
end

#cwe_monitor_enabledBoolean

Indicates whether Application Insights can listen to CloudWatch events for the application resources, such as ‘instance terminated`, `failed deployment`, and others.



175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/aws-sdk-applicationinsights/types.rb', line 175

class ApplicationInfo < Struct.new(
  :account_id,
  :resource_group_name,
  :life_cycle,
  :ops_item_sns_topic_arn,
  :sns_notification_arn,
  :ops_center_enabled,
  :cwe_monitor_enabled,
  :remarks,
  :auto_config_enabled,
  :discovery_type,
  :attach_missing_permission)
  SENSITIVE = []
  include Aws::Structure
end

#discovery_typeString

The method used by Application Insights to onboard your resources.



175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/aws-sdk-applicationinsights/types.rb', line 175

class ApplicationInfo < Struct.new(
  :account_id,
  :resource_group_name,
  :life_cycle,
  :ops_item_sns_topic_arn,
  :sns_notification_arn,
  :ops_center_enabled,
  :cwe_monitor_enabled,
  :remarks,
  :auto_config_enabled,
  :discovery_type,
  :attach_missing_permission)
  SENSITIVE = []
  include Aws::Structure
end

#life_cycleString

The lifecycle of the application.



175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/aws-sdk-applicationinsights/types.rb', line 175

class ApplicationInfo < Struct.new(
  :account_id,
  :resource_group_name,
  :life_cycle,
  :ops_item_sns_topic_arn,
  :sns_notification_arn,
  :ops_center_enabled,
  :cwe_monitor_enabled,
  :remarks,
  :auto_config_enabled,
  :discovery_type,
  :attach_missing_permission)
  SENSITIVE = []
  include Aws::Structure
end

#ops_center_enabledBoolean

Indicates whether Application Insights will create opsItems for any problem detected by Application Insights for an application.



175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/aws-sdk-applicationinsights/types.rb', line 175

class ApplicationInfo < Struct.new(
  :account_id,
  :resource_group_name,
  :life_cycle,
  :ops_item_sns_topic_arn,
  :sns_notification_arn,
  :ops_center_enabled,
  :cwe_monitor_enabled,
  :remarks,
  :auto_config_enabled,
  :discovery_type,
  :attach_missing_permission)
  SENSITIVE = []
  include Aws::Structure
end

#ops_item_sns_topic_arnString

The SNS topic provided to Application Insights that is associated to the created opsItems to receive SNS notifications for opsItem updates.



175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/aws-sdk-applicationinsights/types.rb', line 175

class ApplicationInfo < Struct.new(
  :account_id,
  :resource_group_name,
  :life_cycle,
  :ops_item_sns_topic_arn,
  :sns_notification_arn,
  :ops_center_enabled,
  :cwe_monitor_enabled,
  :remarks,
  :auto_config_enabled,
  :discovery_type,
  :attach_missing_permission)
  SENSITIVE = []
  include Aws::Structure
end

#remarksString

The issues on the user side that block Application Insights from successfully monitoring an application. Example remarks include:

  • “Configuring application, detected 1 Errors, 3 Warnings”

  • “Configuring application, detected 1 Unconfigured Components”



175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/aws-sdk-applicationinsights/types.rb', line 175

class ApplicationInfo < Struct.new(
  :account_id,
  :resource_group_name,
  :life_cycle,
  :ops_item_sns_topic_arn,
  :sns_notification_arn,
  :ops_center_enabled,
  :cwe_monitor_enabled,
  :remarks,
  :auto_config_enabled,
  :discovery_type,
  :attach_missing_permission)
  SENSITIVE = []
  include Aws::Structure
end

#resource_group_nameString

The name of the resource group used for the application.



175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/aws-sdk-applicationinsights/types.rb', line 175

class ApplicationInfo < Struct.new(
  :account_id,
  :resource_group_name,
  :life_cycle,
  :ops_item_sns_topic_arn,
  :sns_notification_arn,
  :ops_center_enabled,
  :cwe_monitor_enabled,
  :remarks,
  :auto_config_enabled,
  :discovery_type,
  :attach_missing_permission)
  SENSITIVE = []
  include Aws::Structure
end

#sns_notification_arnString

The SNS topic ARN that is associated with SNS notifications for updates or issues.



175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/aws-sdk-applicationinsights/types.rb', line 175

class ApplicationInfo < Struct.new(
  :account_id,
  :resource_group_name,
  :life_cycle,
  :ops_item_sns_topic_arn,
  :sns_notification_arn,
  :ops_center_enabled,
  :cwe_monitor_enabled,
  :remarks,
  :auto_config_enabled,
  :discovery_type,
  :attach_missing_permission)
  SENSITIVE = []
  include Aws::Structure
end