Class: Aws::ApplicationInsights::Types::ListLogPatternsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-applicationinsights/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_idString

The Amazon Web Services account ID for the resource group owner.



1134
1135
1136
1137
1138
1139
1140
1141
# File 'lib/aws-sdk-applicationinsights/types.rb', line 1134

class ListLogPatternsResponse < Struct.new(
  :resource_group_name,
  :account_id,
  :log_patterns,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#log_patternsArray<Types::LogPattern>

The list of log patterns.



1134
1135
1136
1137
1138
1139
1140
1141
# File 'lib/aws-sdk-applicationinsights/types.rb', line 1134

class ListLogPatternsResponse < Struct.new(
  :resource_group_name,
  :account_id,
  :log_patterns,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token used to retrieve the next page of results. This value is null when there are no more results to return.



1134
1135
1136
1137
1138
1139
1140
1141
# File 'lib/aws-sdk-applicationinsights/types.rb', line 1134

class ListLogPatternsResponse < Struct.new(
  :resource_group_name,
  :account_id,
  :log_patterns,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#resource_group_nameString

The name of the resource group.



1134
1135
1136
1137
1138
1139
1140
1141
# File 'lib/aws-sdk-applicationinsights/types.rb', line 1134

class ListLogPatternsResponse < Struct.new(
  :resource_group_name,
  :account_id,
  :log_patterns,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end