Class: Aws::ApplicationInsights::Types::ListProblemsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-applicationinsights/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_idString

The Amazon Web Services account ID for the resource group owner.



1215
1216
1217
1218
1219
1220
1221
1222
# File 'lib/aws-sdk-applicationinsights/types.rb', line 1215

class ListProblemsResponse < Struct.new(
  :problem_list,
  :next_token,
  :resource_group_name,
  :account_id)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token used to retrieve the next page of results. This value is null when there are no more results to return.



1215
1216
1217
1218
1219
1220
1221
1222
# File 'lib/aws-sdk-applicationinsights/types.rb', line 1215

class ListProblemsResponse < Struct.new(
  :problem_list,
  :next_token,
  :resource_group_name,
  :account_id)
  SENSITIVE = []
  include Aws::Structure
end

#problem_listArray<Types::Problem>

The list of problems.



1215
1216
1217
1218
1219
1220
1221
1222
# File 'lib/aws-sdk-applicationinsights/types.rb', line 1215

class ListProblemsResponse < Struct.new(
  :problem_list,
  :next_token,
  :resource_group_name,
  :account_id)
  SENSITIVE = []
  include Aws::Structure
end

#resource_group_nameString

The name of the resource group.



1215
1216
1217
1218
1219
1220
1221
1222
# File 'lib/aws-sdk-applicationinsights/types.rb', line 1215

class ListProblemsResponse < Struct.new(
  :problem_list,
  :next_token,
  :resource_group_name,
  :account_id)
  SENSITIVE = []
  include Aws::Structure
end