Class: Aws::ApplicationInsights::Types::UpdateApplicationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-applicationinsights/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attach_missing_permissionBoolean

If set to true, the managed policies for SSM and CW will be attached to the instance roles if they are missing.



1931
1932
1933
1934
1935
1936
1937
1938
1939
1940
1941
1942
# File 'lib/aws-sdk-applicationinsights/types.rb', line 1931

class UpdateApplicationRequest < Struct.new(
  :resource_group_name,
  :ops_center_enabled,
  :cwe_monitor_enabled,
  :ops_item_sns_topic_arn,
  :sns_notification_arn,
  :remove_sns_topic,
  :auto_config_enabled,
  :attach_missing_permission)
  SENSITIVE = []
  include Aws::Structure
end

#auto_config_enabledBoolean

Turns auto-configuration on or off.



1931
1932
1933
1934
1935
1936
1937
1938
1939
1940
1941
1942
# File 'lib/aws-sdk-applicationinsights/types.rb', line 1931

class UpdateApplicationRequest < Struct.new(
  :resource_group_name,
  :ops_center_enabled,
  :cwe_monitor_enabled,
  :ops_item_sns_topic_arn,
  :sns_notification_arn,
  :remove_sns_topic,
  :auto_config_enabled,
  :attach_missing_permission)
  SENSITIVE = []
  include Aws::Structure
end

#cwe_monitor_enabledBoolean

Indicates whether Application Insights can listen to CloudWatch events for the application resources, such as ‘instance terminated`, `failed deployment`, and others.



1931
1932
1933
1934
1935
1936
1937
1938
1939
1940
1941
1942
# File 'lib/aws-sdk-applicationinsights/types.rb', line 1931

class UpdateApplicationRequest < Struct.new(
  :resource_group_name,
  :ops_center_enabled,
  :cwe_monitor_enabled,
  :ops_item_sns_topic_arn,
  :sns_notification_arn,
  :remove_sns_topic,
  :auto_config_enabled,
  :attach_missing_permission)
  SENSITIVE = []
  include Aws::Structure
end

#ops_center_enabledBoolean

When set to true, creates opsItems for any problems detected on an application.



1931
1932
1933
1934
1935
1936
1937
1938
1939
1940
1941
1942
# File 'lib/aws-sdk-applicationinsights/types.rb', line 1931

class UpdateApplicationRequest < Struct.new(
  :resource_group_name,
  :ops_center_enabled,
  :cwe_monitor_enabled,
  :ops_item_sns_topic_arn,
  :sns_notification_arn,
  :remove_sns_topic,
  :auto_config_enabled,
  :attach_missing_permission)
  SENSITIVE = []
  include Aws::Structure
end

#ops_item_sns_topic_arnString

The SNS topic provided to Application Insights that is associated to the created opsItem. Allows you to receive notifications for updates to the opsItem.



1931
1932
1933
1934
1935
1936
1937
1938
1939
1940
1941
1942
# File 'lib/aws-sdk-applicationinsights/types.rb', line 1931

class UpdateApplicationRequest < Struct.new(
  :resource_group_name,
  :ops_center_enabled,
  :cwe_monitor_enabled,
  :ops_item_sns_topic_arn,
  :sns_notification_arn,
  :remove_sns_topic,
  :auto_config_enabled,
  :attach_missing_permission)
  SENSITIVE = []
  include Aws::Structure
end

#remove_sns_topicBoolean

Disassociates the SNS topic from the opsItem created for detected problems.



1931
1932
1933
1934
1935
1936
1937
1938
1939
1940
1941
1942
# File 'lib/aws-sdk-applicationinsights/types.rb', line 1931

class UpdateApplicationRequest < Struct.new(
  :resource_group_name,
  :ops_center_enabled,
  :cwe_monitor_enabled,
  :ops_item_sns_topic_arn,
  :sns_notification_arn,
  :remove_sns_topic,
  :auto_config_enabled,
  :attach_missing_permission)
  SENSITIVE = []
  include Aws::Structure
end

#resource_group_nameString

The name of the resource group.



1931
1932
1933
1934
1935
1936
1937
1938
1939
1940
1941
1942
# File 'lib/aws-sdk-applicationinsights/types.rb', line 1931

class UpdateApplicationRequest < Struct.new(
  :resource_group_name,
  :ops_center_enabled,
  :cwe_monitor_enabled,
  :ops_item_sns_topic_arn,
  :sns_notification_arn,
  :remove_sns_topic,
  :auto_config_enabled,
  :attach_missing_permission)
  SENSITIVE = []
  include Aws::Structure
end

#sns_notification_arnString

The SNS topic ARN. Allows you to receive SNS notifications for updates and issues with an application.



1931
1932
1933
1934
1935
1936
1937
1938
1939
1940
1941
1942
# File 'lib/aws-sdk-applicationinsights/types.rb', line 1931

class UpdateApplicationRequest < Struct.new(
  :resource_group_name,
  :ops_center_enabled,
  :cwe_monitor_enabled,
  :ops_item_sns_topic_arn,
  :sns_notification_arn,
  :remove_sns_topic,
  :auto_config_enabled,
  :attach_missing_permission)
  SENSITIVE = []
  include Aws::Structure
end