Class: Aws::ApplicationInsights::Types::UpdateProblemRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-applicationinsights/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#problem_idString

The ID of the problem.



2119
2120
2121
2122
2123
2124
2125
# File 'lib/aws-sdk-applicationinsights/types.rb', line 2119

class UpdateProblemRequest < Struct.new(
  :problem_id,
  :update_status,
  :visibility)
  SENSITIVE = []
  include Aws::Structure
end

#update_statusString

The status of the problem. Arguments can be passed for only problems that show a status of RECOVERING.



2119
2120
2121
2122
2123
2124
2125
# File 'lib/aws-sdk-applicationinsights/types.rb', line 2119

class UpdateProblemRequest < Struct.new(
  :problem_id,
  :update_status,
  :visibility)
  SENSITIVE = []
  include Aws::Structure
end

#visibilityString

The visibility of a problem. When you pass a value of IGNORED, the problem is removed from the default view, and all notifications for the problem are suspended. When VISIBLE is passed, the IGNORED action is reversed.



2119
2120
2121
2122
2123
2124
2125
# File 'lib/aws-sdk-applicationinsights/types.rb', line 2119

class UpdateProblemRequest < Struct.new(
  :problem_id,
  :update_status,
  :visibility)
  SENSITIVE = []
  include Aws::Structure
end